### Name: run.jags
### Title: RUN A USER SPECIFIED MODEL IN JAGS FROM WITHIN R
### Aliases: run.jags run.JAGS
### Keywords: models

### ** Examples

# run a model to calculate the intercept and slope of the expression y = m x + c, assuming normal observation errors for y:

## Not run: 
##D # Simulate the data
##D x <- 1:100
##D y <- rnorm(length(x), 2*x + 10, 1)
##D 
##D # Model in the JAGS format
##D model <- "model {
##D for(i in 1 : n){
##D y[i] ~ dnorm(true.y[i], precision);
##D true.y[i] <- (m * x[i]) + c;
##D }
##D m ~ dunif(-1000,1000);
##D c ~ dunif(-1000,1000);
##D precision ~ dexp(1);
##D }"
##D 
##D # Use dump.format to convert the data and initial values files into the R dump format
##D data <- dump.format(c("x", "y", "n"), list(x, y, length(x)))
##D inits1 <- dump.format(c("m", "c", "precision"), list(1, 1, 1))
##D inits2 <- dump.format(c("m", "c", "precision"), list(0.1, 10, 1))
##D 
##D # Run the model
##D results <- run.jags(data=data, model=model, inits=c(inits1,
##D inits2), monitor=c("m", "c", "precision"))
##D 
##D # Analyse the results
##D m <- summary(c(results[[1]][,1], results[[2]][,1]))
##D c <- summary(c(results[[1]][,2], results[[2]][,2]))
##D p <- summary(c(results[[1]][,3], results[[2]][,3]))
## End(Not run)




